Colour
======

.. toctree::
    :maxdepth: 3

    colour.adaptation
    colour.algebra
    colour.appearance
    colour.biochemistry
    colour.blindness
    colour.characterisation
    colour.colorimetry
    colour.constants
    colour.contrast
    colour.continuous
    colour.corresponding
    colour.difference
    colour.geometry
    colour.graph
    colour.hints
    colour.io
    colour.models
    colour.notation
    colour.phenomena
    colour.plotting
    colour.quality
    colour.recovery
    colour.temperature
    colour.utilities
    colour.volume
